@@ -7,6 +7,8 @@ _eval_metric_util = _catboost._eval_metric_util
 _get_roc_curve = _catboost._get_roc_curve
 _select_threshold = _catboost._select_threshold
 
+compute_wx_test = _catboost.compute_wx_test
+
 
 def create_cd(
     label=None,
@@ -85,7 +87,7 @@ def eval_metric(label, approx, metric, weight=None, group_id=None, thread_count=
 
     thread_count : int, optional (default=-1)
         Number of threads to work with.
-        If -1, then the number of threads is set to the number of cores.
+        If -1, then the number of threads is set to the number of CPU cores.
 
     Returns
     -------
@@ -120,7 +122,7 @@ def get_roc_curve(model, data, thread_count=-1):
 
     thread_count : int (default=-1)
         Number of threads to work with.
-        If -1, then the number of threads is set to the number of cores.
+        If -1, then the number of threads is set to the number of CPU cores.
 
     Returns
     -------
@@ -155,7 +157,7 @@ def get_fpr_curve(model=None, data=None, curve=None, thread_count=-1):
 
     thread_count : int (default=-1)
         Number of threads to work with.
-        If -1, then the number of threads is set to the number of cores.
+        If -1, then the number of threads is set to the number of CPU cores.
 
     Returns
     -------
@@ -192,7 +194,7 @@ def get_fnr_curve(model=None, data=None, curve=None, thread_count=-1):
 
     thread_count : int (default=-1)
         Number of threads to work with.
-        If -1, then the number of threads is set to the number of cores.
+        If -1, then the number of threads is set to the number of CPU cores.
 
     Returns
     -------
@@ -235,7 +237,7 @@ def select_threshold(model=None, data=None, curve=None, FPR=None, FNR=None, thre
 
     thread_count : int (default=-1)
         Number of threads to work with.
-        If -1, then the number of threads is set to the number of cores.
+        If -1, then the number of threads is set to the number of CPU cores.
 
     Returns
     -------
